Crate spl_type_length_value
source ·Expand description
Crate defining an interface for managing type-length-value entries in a slab of bytes, to be used with Solana accounts.
Re-exports
pub use solana_program;
Modules
- Error types
- Module for the length portion of a Type-Length-Value structure
- Pod types to be used with bytemuck for zero-copy serde
- Type-length-value structure definition and manipulation