Pod types to be used with bytemuck for zero-copy serde

Structs

  • The standard bool is not a Pod, define a replacement that is
  • Special type for using a slice of Pods in a zero-copy way
  • Special type for using a slice of mutable Pods in a zero-copy way
  • u32 type that can be used in Pods

Functions