pub struct TlvStateMut<'data> { /* private fields */ }
Encapsulates mutable base state data (mint or account) with possible extensions

Implementations

source

impl<'data> TlvStateMut<'data>

source

pub fn unpack(data: &'data mut [u8]) -> Result<Self, ProgramError>

Unpacks TLV state data

Fails if no state is initialized or if data is too small

source

pub fn get_value_mut<V: SplDiscriminate + Pod>( &mut self ) -> Result<&mut V, ProgramError>

Unpack a portion of the TLV data as the desired type that allows modifying the type

source

pub fn get_bytes_mut<V: SplDiscriminate>( &mut self ) -> Result<&mut [u8], ProgramError>

Unpack a portion of the TLV data as mutable bytes

source

pub fn init_value<V: SplDiscriminate + Pod + Default>( &mut self ) -> Result<&mut V, ProgramError>

Packs the default TLV data into the first open slot in the data buffer. If extension is already found in the buffer, it returns an error.

source

pub fn alloc<V: SplDiscriminate>( &mut self, length: usize ) -> Result<&mut [u8], ProgramError>

Allocate the given number of bytes for the given SplDiscriminate

source

pub fn realloc<V: SplDiscriminate>( &mut self, length: usize ) -> Result<&mut [u8], ProgramError>

Reallocate the given number of bytes for the given SplDiscriminate. If the new length is smaller, it will compact the rest of the buffer and zero out the difference at the end. If it’s larger, it will move the rest of the buffer data and zero out the new data.